==> okareo-0.0.30-py3-none-any.whl: okareo_api_client/api/default/run_test_v0_test_run_post.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.error_response import ErrorResponse
from ...models.test_run_item import TestRunItem
from ...models.test_run_payload_v2 import TestRunPayloadV2
from ...types import Response


def _get_kwargs(
    *,
    json_body: TestRunPayloadV2,
    api_key: str,
) -> Dict[str, Any]:
    headers = {}
    headers["api-key"] = api_key

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "/v0/test_run",
        "json": json_json_body,
        "headers": headers,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[ErrorResponse, TestRunItem]]:
    if response.status_code == HTTPStatus.CREATED:
        response_201 = TestRunItem.from_dict(response.json())

        return response_201
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = ErrorResponse.from_dict(response.json())

        return response_400
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = ErrorResponse.from_dict(response.json())

        return response_404
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = ErrorResponse.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[ErrorResponse, TestRunItem]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestRunPayloadV2,
    api_key: str,
) -> Response[Union[ErrorResponse, TestRunItem]]:
    """Run Test

     Runs tests on a model (mut_id) using previously generated scenario.
    Feeds the scenario data (scenario_id) into the model and evaulates results
    depending on the test type specified.

    Returns:
        The test run data which includes the evaluated metrics from the run.

    Args:
        api_key (str):
        json_body (TestRunPayloadV2):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ErrorResponse, TestRunItem]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestRunPayloadV2,
    api_key: str,
) -> Optional[Union[ErrorResponse, TestRunItem]]:
    """Run Test

     Runs tests on a model (mut_id) using previously generated scenario.
    Feeds the scenario data (scenario_id) into the model and evaulates results
    depending on the test type specified.

    Returns:
        The test run data which includes the evaluated metrics from the run.

    Args:
        api_key (str):
        json_body (TestRunPayloadV2):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ErrorResponse, TestRunItem]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        api_key=api_key,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestRunPayloadV2,
    api_key: str,
) -> Response[Union[ErrorResponse, TestRunItem]]:
    """Run Test

     Runs tests on a model (mut_id) using previously generated scenario.
    Feeds the scenario data (scenario_id) into the model and evaulates results
    depending on the test type specified.

    Returns:
        The test run data which includes the evaluated metrics from the run.

    Args:
        api_key (str):
        json_body (TestRunPayloadV2):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ErrorResponse, TestRunItem]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestRunPayloadV2,
    api_key: str,
) -> Optional[Union[ErrorResponse, TestRunItem]]:
    """Run Test

     Runs tests on a model (mut_id) using previously generated scenario.
    Feeds the scenario data (scenario_id) into the model and evaulates results
    depending on the test type specified.

    Returns:
        The test run data which includes the evaluated metrics from the run.

    Args:
        api_key (str):
        json_body (TestRunPayloadV2):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ErrorResponse, TestRunItem]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            api_key=api_key,
        )
    ).parsed

==> okareo-0.0.68-py3-none-any.whl: okareo_api_client/api/default/run_test_v0_test_run_post.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.error_response import ErrorResponse
from ...models.test_run_item import TestRunItem
from ...models.test_run_payload_v2 import TestRunPayloadV2
from ...types import Response


def _get_kwargs(
    *,
    json_body: TestRunPayloadV2,
    api_key: str,
) -> Dict[str, Any]:
    headers = {}
    headers["api-key"] = api_key

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "/v0/test_run",
        "json": json_json_body,
        "headers": headers,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[ErrorResponse, TestRunItem]]:
    if response.status_code == HTTPStatus.CREATED:
        response_201 = TestRunItem.from_dict(response.json())

        return response_201
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = ErrorResponse.from_dict(response.json())

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = ErrorResponse.from_dict(response.json())

        return response_401
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = ErrorResponse.from_dict(response.json())

        return response_404
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = ErrorResponse.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[ErrorResponse, TestRunItem]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestRunPayloadV2,
    api_key: str,
) -> Response[Union[ErrorResponse, TestRunItem]]:
    """Run Test

     Runs tests on a model (mut_id) using previously generated scenario.
    Feeds the scenario data (scenario_id) into the model and evaulates results
    depending on the test type specified.

    Returns:
        The test run data which includes the evaluated metrics from the run.

    Args:
        api_key (str):
        json_body (TestRunPayloadV2):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ErrorResponse, TestRunItem]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestRunPayloadV2,
    api_key: str,
) -> Optional[Union[ErrorResponse, TestRunItem]]:
    """Run Test

     Runs tests on a model (mut_id) using previously generated scenario.
    Feeds the scenario data (scenario_id) into the model and evaulates results
    depending on the test type specified.

    Returns:
        The test run data which includes the evaluated metrics from the run.

    Args:
        api_key (str):
        json_body (TestRunPayloadV2):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ErrorResponse, TestRunItem]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        api_key=api_key,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestRunPayloadV2,
    api_key: str,
) -> Response[Union[ErrorResponse, TestRunItem]]:
    """Run Test

     Runs tests on a model (mut_id) using previously generated scenario.
    Feeds the scenario data (scenario_id) into the model and evaulates results
    depending on the test type specified.

    Returns:
        The test run data which includes the evaluated metrics from the run.

    Args:
        api_key (str):
        json_body (TestRunPayloadV2):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[ErrorResponse, TestRunItem]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        api_key=api_key,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: TestRunPayloadV2,
    api_key: str,
) -> Optional[Union[ErrorResponse, TestRunItem]]:
    """Run Test

     Runs tests on a model (mut_id) using previously generated scenario.
    Feeds the scenario data (scenario_id) into the model and evaulates results
    depending on the test type specified.

    Returns:
        The test run data which includes the evaluated metrics from the run.

    Args:
        api_key (str):
        json_body (TestRunPayloadV2):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[ErrorResponse, TestRunItem]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            api_key=api_key,
        )
    ).parsed
